@@ -2,13 +2,22 @@
 Implements a client class to query the
 `Deezer API <http://developers.deezer.com/api>`_
 """
-import requests
 from urllib.parse import urlencode
 
+import requests
+
+from deezer.resources import (
+    Album,
+    Artist,
+    Chart,
+    Comment,
+    Genre,
+    Playlist,
+    Radio,
+    Track,
+    User,
+)
 from deezer.utils import SortedDict
-from deezer.resources import Album, Artist, Comment, Genre
-from deezer.resources import Chart, Resource
-from deezer.resources import Playlist, Radio, Track, User
 
 
 class Client:
@@ -23,6 +32,12 @@ class Client:
 
     This client provides several method to retrieve the content of most
     sort of Deezer objects, based on their json structure.
+
+    Headers can be forced by using the ``headers`` kwarg.
+    For example, use ``Accept-Language`` header to force the output language.
+
+        >>> import deezer
+        >>> client = deezer.Client(headers={'Accept-Language': 'fr'})
     """
 
     use_ssl = True
@@ -54,6 +69,10 @@ class Client:
         if kwargs.get("do_not_compress_reponse"):
             self.session.headers.update({"Accept-Encoding": "identity"})
 
+        # Headers
+        if kwargs.get("headers"):
+            self.session.headers.update(kwargs.get("headers"))
+
         self.options = kwargs
         self._authorize_url = None
 
@@ -80,9 +99,9 @@ class Client:
             result[parent.type] = parent
 
         if "type" in result:
-            object_class = self.objects_types.get(result["type"], Resource)
+            object_class = self.objects_types[result["type"]]
         else:
-            object_class = self.objects_types.get(parent, Resource)
+            object_class = self.objects_types[parent]
         return object_class(self, result)
 
     @property
@@ -135,7 +154,12 @@ class Client:
         """
         url = self.object_url(object_t, object_id, relation, **kwargs)
         response = self.session.get(url)
-        return self._process_json(response.json(), parent)
+        json = response.json()
+        if "error" in json:
+            raise ValueError(
+                "API request return error for object: %s id: %s" % (object_t, object_id)
+            )
+        return self._process_json(json, parent)
 
     def get_chart(self, relation=None, index=0, limit=10, **kwargs):
         """
@@ -256,7 +280,8 @@ class Client:
         >>> client.advanced_search({"artist": "Daft Punk", "album": "Homework"},
         ...                        relation="track")
         """
-        assert isinstance(terms, dict), "terms must be a dict"
+        if not isinstance(terms, dict):
+            raise TypeError("terms must be a dict")
         # terms are sorted (for consistent tests between Python < 3.7 and >= 3.7)
         query = " ".join(sorted(['{}:"{}"'.format(k, v) for (k, v) in terms.items()]))
         return self.get_object(
